==> nextcloud-30.0.5.tgz: nextcloud/apps/twofactor_totp/l10n/de_DE.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Sie haben TOTP als Zwei-Faktor-Authentifizierung für Ihr Konto aktiviert",
    "You disabled TOTP two-factor authentication for your account" : "Sie haben TOTP als Zwei-Faktor-Authentifizierung für Ihr Konto deaktiviert",
    "TOTP two-factor authentication disabled by the administration" : "TOTP-Zwei-Faktor-Authentifizierung von der Administration deaktiviert",
    "TOTP (Authenticator app)" : "TOTP (Authenticator-App)",
    "Authenticate with a TOTP app" : "Mit einer TOTP-App authentifizieren",
    "Two-Factor TOTP Provider" : "Zwei-Faktor TOTP-Anbieter",
    "Two-factor TOTP provider" : "Zwei-Faktor TOTP-Anbieter",
    "A two-factor authentication provider for TOTP (RFC 6238)" : "Ein Zwei-Faktor-Authentifizierungsanbieter für TOTP (RFC 6238)",
    "Enable TOTP" : "TOTP aktivieren",
    "Could not enable TOTP" : "TOTP konnte nicht aktiviert werden",
    "Could not verify your key. Please try again" : "Ihr Schlüssel konnte nicht überprüft werden. Bitte erneut versuchen.",
    "Your new TOTP secret is:" : "Ihr neuer TOTP-Schlüssel ist:",
    "For quick setup, scan this QR code with your TOTP app:" : "Für eine schnelle Einrichtung diesen QR-Code mit der TOTP-App scannen:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "Nachdem Sie die App konfiguriert haben, geben Sie unten einen Testcode ein, um sicherzustellen, dass alles funktioniert:",
    "Authentication code" : "Authentifizierungscode",
    "Verify" : "Überprüfen",
    "Get the authentication code from the two-factor authentication app on your device." : "Erhalten Sie den Authentifizierungscode von der Zweifaktorauthentifizierungs-App auf Ihrem Gerät ",
    "Submit" : "Übermitteln",
    "TOTP two-factor authentication disabled by an admin" : "TOTP als Zwei-Faktor-Authentifizierung wurde von der Administration deaktiviert",
    "TOTP two-factor provider" : "TOTP-Zwei-Faktor-Anbieter",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "Ein Anbieter für Zwei-Faktor-Authentifizierung für TOTP (RFC 6238)"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.1.tgz: nextcloud/apps/twofactor_totp/l10n/de_DE.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Sie haben TOTP als Zwei-Faktor-Authentifizierung für Ihr Konto aktiviert",
    "You disabled TOTP two-factor authentication for your account" : "Sie haben TOTP als Zwei-Faktor-Authentifizierung für Ihr Konto deaktiviert",
    "TOTP two-factor authentication disabled by the administration" : "TOTP Zwei-Faktor-Authentifizierung von der Administration deaktiviert",
    "TOTP (Authenticator app)" : "TOTP (Authenticator-App)",
    "Authenticate with a TOTP app" : "Mit einer TOTP-App authentifizieren",
    "Two-Factor TOTP Provider" : "Zwei-Faktor TOTP-Anbieter",
    "Two-factor TOTP provider" : "Zwei-Faktor TOTP-Anbieter",
    "A two-factor authentication provider for TOTP (RFC 6238)" : "Ein Zwei-Faktor-Authentifizierungsanbieter für TOTP (RFC 6238)",
    "Could not enable TOTP" : "TOTP konnte nicht aktiviert werden",
    "Could not verify your key. Please try again" : "Ihr Schlüssel konnte nicht überprüft werden. Bitte erneut versuchen.",
    "Enable TOTP" : "TOTP aktivieren",
    "Your new TOTP secret is:" : "Ihr neuer TOTP-Schlüssel ist:",
    "For quick setup, scan this QR code with your TOTP app:" : "Für eine schnelle Einrichtung diesen QR-Code mit der TOTP-App scannen:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "Nachdem Sie die App konfiguriert haben, geben Sie unten einen Testcode ein, um sicherzustellen, dass alles funktioniert:",
    "Authentication code" : "Authentifizierungscode",
    "Verify" : "Überprüfen",
    "Get the authentication code from the two-factor authentication app on your device." : "Erhalten Sie den Authentifizierungscode von der Zwei-Faktor-Authentifizierungs-App auf Ihrem Gerät ",
    "Submit" : "Übermitteln"
},
"nplurals=2; plural=(n != 1);");
